==> gnome_icon_theme-2.10.0-i386-P1.tgz: install/doinst.sh <==
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-qif.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-qw.png gnome-mime-application-qif.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-backup.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-trash.png gnome-mime-application-x-backup.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-core-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-core.png gnome-mime-application-x-core-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-desktop.png gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-class-file.png gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-object-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-object.png gnome-mime-application-x-object-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-smil.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-smil.png gnome-mime-application-x-smil.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-audio-x-midi.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-audio-midi.png gnome-mime-audio-x-midi.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-image-svg.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-image-svg+xml.png gnome-mime-image-svg.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c-header.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-chdr.png gnome-mime-text-x-c-header.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-csrc.png gnome-mime-text-x-c.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-c++src.png gnome-mime-text-x-c++.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-shellscript.png gnome-mime-text-x-sh.png )
( cd usr/share/doc/gnome-icon-theme-2.10.0 ; rm -rf build )
( cd usr/share/doc/gnome-icon-theme-2.10.0 ; ln -sf /usr/src/garnome-Ptgz-kit build )

==> gnome_icon_theme-2.12.1-i386-P1.tgz: install/doinst.sh <==
( cd usr/share/doc/gnome-icon-theme-2.12.1 ; rm -rf build )
( cd usr/share/doc/gnome-icon-theme-2.12.1 ; ln -sf /usr/src/garnome-Ptgz-kit build )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-object-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-object.png gnome-mime-application-x-object-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-audio-x-midi.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-audio-midi.png gnome-mime-audio-x-midi.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-class-file.png gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-c++src.png gnome-mime-text-x-c++.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-qif.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-qw.png gnome-mime-application-qif.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-desktop.png gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-shellscript.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-backup.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-trash.png gnome-mime-application-x-backup.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-csrc.png gnome-mime-text-x-c.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-smil.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-smil.png gnome-mime-application-x-smil.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-text-x-c-header.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-text-x-chdr.png gnome-mime-text-x-c-header.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-image-svg.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-image-svg+xml.png gnome-mime-image-svg.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; rm -rf gnome-mime-application-x-core-file.png )
( cd usr/share/icons/gnome/48x48/mimetypes ; ln -sf gnome-mime-application-x-core.png gnome-mime-application-x-core-file.png )
( cd usr/share/icons/hicolor/16x16/filesystems ; rm -rf gnome-fs-share-private.png )
( cd usr/share/icons/hicolor/16x16/filesystems ; ln -sf /usr/share/icons/hicolor/16x16/stock/net/stock_shared-to-me.png gnome-fs-share-private.png )
( cd usr/share/icons/hicolor/16x16/filesystems ; rm -rf gnome-fs-locally-shared.png )
( cd usr/share/icons/hicolor/16x16/filesystems ; ln -sf /usr/share/icons/hicolor/16x16/stock/net/stock_shared-by-me.png gnome-fs-locally-shared.png )
( cd usr/share/icons/hicolor/24x24/filesystems ; rm -rf gnome-fs-share-private.png )
( cd usr/share/icons/hicolor/24x24/filesystems ; ln -sf /usr/share/icons/hicolor/24x24/stock/net/stock_shared-to-me.png gnome-fs-share-private.png )
( cd usr/share/icons/hicolor/24x24/filesystems ; rm -rf gnome-fs-locally-shared.png )
( cd usr/share/icons/hicolor/24x24/filesystems ; ln -sf /usr/share/icons/hicolor/24x24/stock/net/stock_shared-by-me.png gnome-fs-locally-shared.png )
